struct Block {
label_id: Word,
body: Vec<Instruction>,
}Expand description
A SPIR-V block to which we are still adding instructions.
A Block represents a SPIR-V block that does not yet have a termination
instruction like OpBranch or OpReturn.
The OpLabel that starts the block is implicit. It will be emitted based on
label_id when we write the block to a LogicalLayout.
To terminate a Block, pass the block and the termination instruction to
Function::consume. This takes ownership of the Block and transforms it
into a TerminatedBlock.
Fields
label_id: Wordbody: Vec<Instruction>Implementations